# Ranko the Raccoon

Ranko is the mascott of the [numbro](https://github.com/foretagsplatsen/numbro) project.

This folder provides the material related to Ranko.


### License

Copyright © 2015 Benjamin Van Ryseghem

All the files in this folder are distributed under the **CC BY-NC-SA 4.0** license. See `LICENSE` for more informations.

<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png" /></a><br /><span xmlns:dct="http://purl.org/dc/terms/" href="http://purl.org/dc/dcmitype/StillImage" property="dct:title" rel="dct:type">Ranko the Raccoon</span> by <a xmlns:cc="http://creativecommons.org/ns#" href="https://benjamin.vanryseghem.com" property="cc:attributionName" rel="cc:attributionURL">Benjamin Van Ryseghem</a> is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/">Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License</a>.